# Generated by Django 3.2 on 2023-01-30 09:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('email_verification', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='token',
            name='valid',
        ),
    ]
