<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Document</title>
    <style>
        .wrapper {
            border: 2px solid #000;
            padding: 1em;
            font-size: 1.3rem;
            font-family: Helvetica;
            font-weight: 300;
            text-align: center;
            color: #000; 
        }
        a {
        	color: blue;
        	text-decoration: none;
        }
    </style>
</head>
<body>
    <main>
    	<div class="wrapper">
	        <p>Your registration process is almost done. Please confirm your email by clicking on the link below to finish signing up.</p>
	        <p>Visit this <a href="{{ request.scheme }}://{{ request.get_host }}{% url 'verify_email:pre-login' token %}">link</a> to complete the process.</p>
	       
	        <p>This link will expire after 5 minutes.</p>
        </div>
    </main>
</body>
</html>