<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Email Verification Success</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        body {
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
            background: #27282c;
            color: #fff;
        }
        .wrapper {
            padding: 10%;
            text-align: center;
        }
        .text {
            letter-spacing: 2px;
            font-weight: 400;
            font-size: 1.4rem;
            font-family: Helvetica;
            margin-bottom: 2em;
        }
        #btn {
            background: #fff;
            box-shadow: hsl(0,0%,80%) 0 0 4px;
            padding: 10px 35px;
            border-radius: 10px;
            color: red;
            text-decoration: none;
        }
    </style>
</head>
<body>
    <main>
        <div class="wrapper">
            <div class="text">
                <p>Your email has been verified. You can now visit the site to log in.</p>
            </div>
            <a id="btn" href="{% url login_url %}">Login</a>
        </div>
    </main>
</body>
</html>